#!/usr/bin/env python2

##
# autosign
# https://github.com/leosartaj/autosign.git
# 
# copyright (c) 2014 sartaj singh
# licensed under the mit license.
##

"""
Define description variable
"""

from version import __version__

__desc__ = 'autosign  ' + __version__
