#!/usr/bin/env python2

##
# autosign
# https://github.com/leosartaj/autosign.git
# 
# copyright (c) 2014 sartaj singh
# licensed under the mit license.
##

from autosign import __version__

try:
    from setuptools import setup, find_packages
except ImportError:
    from distutils.core import setup, find_packages

setup(
    name = 'autosign',
    version = __version__,
    author = 'Sartaj Singh',
    author_email = 'singhsartaj94@gmail.com',
    description = ('Adds signature to your python files'),
    long_description = open('README.rst').read(),
    license = 'MIT',
    keywords = 'auto signature autosign',
    url = 'http://github.com/leosartaj/autosign',
    packages=find_packages(),
    scripts=['bin/autosign', 'bin/remsign', 'bin/listsign'],
    classifiers=[
        'Development Status :: 3 - Alpha',
        'License :: OSI Approved :: MIT License',
        'Environment :: Console',
        'Natural Language :: English',
        'Programming Language :: Python :: 2.7',
    ],
)

